.. _all-salt.grains:

==============
grains modules
==============

.. currentmodule:: salt.grains

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    core
    disks
    extra
    lvm
    mdadm
    minion_process
    opts
    package
    pending_reboot
    rest_sample
